@@ -84,27 +84,25 @@ class BtVCSGui(QtWidgets.QWidget):
             updateButton = QtWidgets.QPushButton(standardIcon(self, "SP_ArrowDown"),
                                                  self.tr("Update"))
             updateButton.clicked.connect(self.updateRepository)
-            buttonLayout.addWidget(updateButton)
-            buttonLayout.addStretch()
-            openJabrefButton = QtWidgets.QPushButton(self.tr("JabRef"))
-            openJabrefButton.clicked.connect(self.jabref)
-            buttonLayout.addWidget(openJabrefButton)
-            buttonLayout.addStretch()
-            makeHTMLButton = QtWidgets.QPushButton(self.tr("HTML"))
-            makeHTMLButton.setToolTip(self.tr('Create and open a HTML page for the database'))
-            makeHTMLButton.clicked.connect(self.makeHTML)
-            buttonLayout.addWidget(makeHTMLButton)
-            buttonLayout.addStretch()
+            jabrefButton = QtWidgets.QPushButton(self.tr("JabRef"))
+            jabrefButton.clicked.connect(self.jabref)
+            exportButton = QtWidgets.QPushButton(self.tr("Create HTML"))
+            exportButton.setToolTip(self.tr('Create and open a HTML page for the database'))
+            exportButton.clicked.connect(self.makeHTML)
+            self.linkButton = QtWidgets.QPushButton(self.tr("Public HTML"))
+            self.linkButton.clicked.connect(self.publicHTML)
             commitButton = QtWidgets.QPushButton(standardIcon(self, "SP_ArrowUp"),
                                                  self.tr("Commit"))
             commitButton.clicked.connect(self.runChecks)
-            buttonLayout.addWidget(commitButton)
+            for button in updateButton, jabrefButton, exportButton, self.linkButton, commitButton:
+                buttonLayout.addWidget(button)
             self.journalsTable = JournalsWidget(self.db)
             self.layout().addWidget(self.journalsTable)
             self.layout().addLayout(buttonLayout)
             self.guiComplete = True
         else:
             self.journalsTable.setDB(db)
+        self.linkButton.setVisible(db.publicLink is not None)
         db.vcs.authCallback = functools.partial(LoginDialog.getLogin, self)
         self.dbLabel.setText(self.tr("Database: <i>{}</i>").format(db.directory))
         self.setWindowTitle(self.tr("BibTeX VCS – {}").format(db.name))
